@@ -31,18 +31,18 @@
 #include "globus_common.h"
 #include "globus_gridftp_server_control.h"
 
+#ifdef TARGET_ARCH_WIN32
+#ifdef interface
+#undef interface
+#endif
+#endif
+
+#ifndef TARGET_ARCH_WIN32
+#include <grp.h>
+#endif
+
 #define GLOBUS_MAPPING_STRING ":globus-mapping:"
 
-#define _GSSL(s) globus_common_i18n_get_string_by_key(\
-		    NULL, \
-		    "globus_gridftp_server", \
-		    s)
-
-#define _FSSL(s,p) globus_common_i18n_get_string_by_key(\
-		     p, \
-		    "globus_gridftp_server", \
-		    s)
-
 extern globus_module_descriptor_t      globus_i_gfs_module;
 #define GLOBUS_GRIDFTP_SERVER_MODULE (&globus_i_gfs_module)
 
@@ -121,6 +121,10 @@ typedef enum globus_gfs_command_type_e
     GLOBUS_GFS_CMD_SITE_UTIME,
     GLOBUS_GFS_CMD_SITE_SYMLINKFROM,
     GLOBUS_GFS_CMD_SITE_SYMLINK,
+    GLOBUS_GFS_CMD_HTTP_PUT,
+    GLOBUS_GFS_CMD_HTTP_GET,
+    GLOBUS_GFS_CMD_HTTP_CONFIG,
+    GLOBUS_GFS_CMD_TRNC,
     
     /* handled internally */
     GLOBUS_GFS_CMD_SITE_RESTRICT = 3072,
